@@ -616,6 +616,9 @@ ags_effect_bulk_connect(AgsConnectable *connectable)
     return;
   }
 
+  effect_bulk->flags |= AGS_EFFECT_BULK_CONNECTED;
+  
+  /*  */
   g_signal_connect(G_OBJECT(effect_bulk->add), "clicked\0",
 		   G_CALLBACK(ags_effect_bulk_add_callback), effect_bulk);
 
@@ -654,13 +657,37 @@ ags_effect_bulk_disconnect(AgsConnectable *connectable)
 {
   AgsEffectBulk *effect_bulk;
 
+  GList *list, *list_start;
+
   effect_bulk = AGS_EFFECT_BULK(connectable);
 
   if((AGS_EFFECT_BULK_CONNECTED & (effect_bulk->flags)) == 0){
     return;
   }
 
+  effect_bulk->flags &= (~AGS_EFFECT_BULK_CONNECTED);
+
+  ags_connectable_disconnect(AGS_CONNECTABLE(effect_bulk->plugin_browser));
+
+  list =
+    list_start = gtk_container_get_children((GtkContainer *) effect_bulk->table);
+
+  while(list != NULL){
+    if(AGS_IS_CONNECTABLE(list->data)){
+      ags_connectable_disconnect(AGS_CONNECTABLE(list->data));
+    }
+
+    list = list->next;
+  }
+
+  g_list_free(list_start);
+
   //TODO:JK: implement me
+
+  if(effect_bulk->audio != NULL){
+    g_signal_handlers_disconnect_by_data(effect_bulk->audio,
+					 effect_bulk);
+  }  
 }
 
 gchar*
