@@ -185,12 +185,12 @@ ags_add_sequencer_editor_jack_launch(AgsTask *task)
   gui_thread = (AgsGuiThread *) ags_thread_find_type((AgsThread *) main_loop,
 						      AGS_TYPE_GUI_THREAD);
   /*  */
-  pthread_mutex_lock(gui_thread->dispatch_mutex);
+  gdk_threads_enter();
 
   ags_sequencer_editor_add_jack(AGS_ADD_SEQUENCER_EDITOR_JACK(task)->sequencer_editor,
 				NULL);
 
-  pthread_mutex_unlock(gui_thread->dispatch_mutex);
+  gdk_threads_leave();
 
   /* unlock gdk threads */
   gdk_threads_leave();
